"""
Tests of the EpochArray class
"""

try:
    import unittest2 as unittest
except ImportError:
    import unittest

from neo.core.epocharray import EpochArray

class TestEpochArray(unittest.TestCase):
    pass


if __name__ == "__main__":
    unittest.main()
